aboutsummaryrefslogtreecommitdiff
path: root/ndk-gdb.py
diff options
context:
space:
mode:
authorDan Albert <danalbert@google.com>2015-11-16 16:08:30 -0800
committerDan Albert <danalbert@google.com>2015-11-16 16:13:38 -0800
commitc40ed00f635349c4f563c198bb93852784f3cd32 (patch)
treed641f184293bda949bd70bc5996bafc0370c87bb /ndk-gdb.py
parenta0740883293b9e4710585d71db3dba820526d082 (diff)
downloadndk-c40ed00f635349c4f563c198bb93852784f3cd32.tar.gz
Move host-tools into its own directory.
We don't want the various NDK module packages to have overlapping paths. Bug: http://b/25454836 Change-Id: I94f9b153434553d518e677e53df079343e019327
Diffstat (limited to 'ndk-gdb.py')
-rwxr-xr-xndk-gdb.py10
1 files changed, 6 insertions, 4 deletions
diff --git a/ndk-gdb.py b/ndk-gdb.py
index fba4250cd..4d7871a73 100755
--- a/ndk-gdb.py
+++ b/ndk-gdb.py
@@ -32,7 +32,7 @@ import xml.etree.cElementTree as ElementTree
import logging
# Shared functions across gdbclient.py and ndk-gdb.py.
# ndk-gdb is installed to $NDK/prebuilt/bin
NDK_PATH = os.path.normpath(os.path.join(os.path.dirname(__file__), '../..'))
sys.path.append(os.path.join(NDK_PATH, "python-packages"))
import gdbrunner
@@ -182,7 +182,7 @@ def extract_launchable(xmlroot):
def ndk_bin_path():
- path = os.path.join(NDK_PATH, "prebuilt", "bin")
+ path = os.path.join(NDK_PATH, "host-tools", "bin")
if not os.path.exists(path):
error("Failed to find ndk binary path, should be at '{}'".format(path))
@@ -559,8 +559,10 @@ def find_pretty_printer(pretty_printer):
elif pretty_printer == "stlport":
path = os.path.join("stlport", "stlport")
function = "register_stlport_printers"
- return (os.path.join(NDK_PATH, "prebuilt", "share", "pretty-printers", path),
- function)
+ pp_path = os.path.join(
+ NDK_PATH, "host-tools", "share", "pretty-printers", path)
+ return pp_path, function
+
def main():
args = handle_args()
@@ -32,7 +32,7 @@ import xml.etree.cElementTree as ElementTree
import logging
# Shared functions across gdbclient.py and ndk-gdb.py.
-# ndk-gdb is installed to $NDK/prebuilt/bin
+# ndk-gdb is installed to $NDK/host-tools/bin
NDK_PATH = os.path.normpath(os.path.join(os.path.dirname(__file__), '../..'))
sys.path.append(os.path.join(NDK_PATH, "python-packages"))